package services

import (
	"errors"
	"fmt"
	"hongze/hongze_web_mfyx/models"
	"hongze/hongze_web_mfyx/models/order"
	"hongze/hongze_web_mfyx/utils"
	"time"
)

// 获取日卡、月卡商品配置信息
func GetUserGoodsCardList() (goodsListResp []*order.CygxGoodsResp) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg(fmt.Sprint("获取日卡、月卡商品配置信息失败 GetUserGoodsCardList, err：", err.Error()), 2)
		}
	}()
	var condition string
	var pars []interface{}
	condition = ` AND  goods_id IN  (1,2) `
	goodsList, e := order.GetCygxGoodsList(condition, pars)
	if e != nil {
		err = errors.New("GetCygxGoodsList, Err: " + e.Error())
		return
	}
	goodsListResp = goodsList
	return
}

// 获取单场活动关联的商品配置信息
func GetGoodsInfoByActivity(item *models.ActivityDetail) (goodsListResp []*order.CygxGoodsResp) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg(fmt.Sprint("获取单场活动关联的商品配置信息失败 GetGoodsInfoByActivity, err：", err.Error()), 2)
		}
	}()
	//var goodsList []*order.CygxGoodsResp
	//var e error
	var condition string
	var pars []interface{}

	if item.ActivityTypeId == 1 && item.IsLimitPeople == 1 { //专家电话会。限制人数，
		condition = ` AND  goods_id IN  (3) `
	} else if (item.ActivityTypeId == 5 || item.ActivityTypeId == 8) && item.IsResearchPoints { //买方线下交流/专家线下沙龙。参会人扣点，
		condition = ` AND  goods_id IN  (4) `
	} else if (item.ActivityTypeId == 5 || item.ActivityTypeId == 8) && !item.IsResearchPoints { //买方线下交流/专家线下沙龙。参会人扣点，
		condition = ` AND  goods_id IN  (5) `
	} else if item.ActivityTypeId == 3 && item.IsResearchPoints { //非易董。公司调研电话会参会人扣点
		condition = ` AND  goods_id IN  (6) `
	} else if item.ActivityTypeId == 3 && !item.IsResearchPoints { //非易董。公司调研电话会参会人扣点
		condition = ` AND  goods_id IN  (7) `
	} else if item.ActivityTypeId == 1 && item.IsResearchPoints { //专家电话会，不限制人数，研选扣点(1299元)
		condition = ` AND  goods_id IN  (8) `
	}
	goodsList, e := order.GetCygxGoodsList(condition, pars)
	if e != nil {
		err = errors.New("GetCygxGoodsList, Err: " + e.Error())
		return
	}
	//如果活动有自定义的价格就优先按照自定义的价格来
	if item.ActivityPrice > 0 {
		for k, _ := range goodsList {
			goodsList[k].CurrentPrice = fmt.Sprint(item.ActivityPrice)
		}
	}
	goodsListResp = goodsList
	return
}

// 获取用户十分钟之内是否有相同的订单信息
func GetHaverEquallyOrderByUser10Min(userId, goodsId int) (orderCode string) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg(fmt.Sprint("获取用户十分钟之内是否有相同的订单信息失败 GetHaverEquallyOrderByUser10Min, err：", err.Error()), 2)
		}
	}()
	var condition string
	var pars []interface{}
	endTime := time.Now().Add(-10 * time.Minute)
	condition = ` AND order_status = 1 AND  user_id = ? AND  goods_id = ? AND create_time > ?  ORDER BY order_id DESC  `
	pars = append(pars, userId, goodsId, endTime)
	orderList, e := order.GetCygxOrderList(condition, pars, 0, 1)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetCygxOrderList, Err: " + e.Error())
		return
	}
	if len(orderList) == 0 {
		return
	} else {
		for _, v := range orderList {
			orderCode = v.OrderCode
		}
	}
	return
}

// 获取用户十分钟之内是否有相同的订单信息
func GetHaverEquallyOrderByUser10MinByActivty(userId, sourceId int) (orderCode string, seconds int) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg(fmt.Sprint("获取用户十分钟之内是否有相同的订单信息失败 GetHaverEquallyOrderByUser10MinByActivty, err：", err.Error()), 2)
		}
	}()
	var condition string
	var pars []interface{}
	endTime := time.Now().Add(-10 * time.Minute)
	condition = `  AND order_status = 1  AND source = 'activity' AND  user_id = ? AND  source_id = ? AND create_time > ?  AND register_platform = ? ORDER BY order_id DESC  `
	pars = append(pars, userId, sourceId, endTime, utils.REGISTER_PLATFORM)
	orderList, e := order.GetCygxOrderList(condition, pars, 0, 1)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetCygxOrderList, Err: " + e.Error())
		return
	}
	if len(orderList) == 0 {
		return
	} else {
		for _, v := range orderList {
			orderCode = v.OrderCode
			duration := time.Now().Sub(v.CreateTime)
			// 将时间差转换为秒数
			seconds = 600 - int(duration.Seconds())
		}
	}
	return
}

// 获取用户十分钟之内是否有相同的文章订单信息
func GetHaverEquallyOrderByUser10MinByArticle(userId, sourceId int) (orderCode string, seconds int) {
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg(fmt.Sprint("获取用户十分钟之内是否有相同的文章订单信息失败 GetHaverEquallyOrderByUser10MinByArticle, err：", err.Error()), 2)
		}
	}()
	var condition string
	var pars []interface{}
	endTime := time.Now().Add(-10 * time.Minute)
	condition = `  AND order_status = 1  AND source = 'article' AND  user_id = ? AND  source_id = ? AND create_time > ?  AND register_platform = ?  ORDER BY order_id DESC  `
	pars = append(pars, userId, sourceId, endTime, utils.REGISTER_PLATFORM)
	orderList, e := order.GetCygxOrderList(condition, pars, 0, 1)
	if e != nil && e.Error() != utils.ErrNoRow() {
		err = errors.New("GetCygxOrderList, Err: " + e.Error())
		return
	}
	if len(orderList) == 0 {
		return
	} else {
		for _, v := range orderList {
			orderCode = v.OrderCode
			duration := time.Now().Sub(v.CreateTime)
			// 将时间差转换为秒数
			seconds = 600 - int(duration.Seconds())
		}
	}
	return
}

// GetActivityOrderListLabelKeyword 根据活动ID获取活动自定义类型
func GetActivityOrderListLabelKeywordByActivityIds(activityIds []int) (mapResp map[int]string) {
	lenArr := len(activityIds)
	if lenArr == 0 {
		return
	}
	var err error
	defer func() {
		if err != nil {
			fmt.Println(err)
			go utils.SendAlarmMsg("GetActivityOrderListLabelKeywordByActivityIds，根据活动ID获取活动自定义类型 失败Err："+err.Error(), 2)
		}
	}()
	var condition string
	var pars []interface{}
	//获取所有研选类型的活动
	condition += ` AND activity_id IN (` + utils.GetOrmInReplace(lenArr) + `)   `
	pars = append(pars, activityIds)
	listActivity, e := models.GetActivityListByCondition(condition, pars)
	if e != nil {
		err = errors.New("GetActivityListByCondition, Err: " + e.Error())
		return
	}
	mapResp = make(map[int]string, 0)
	for _, v := range listActivity {
		switch v.ActivityTypeId {
		case 1:
			mapResp[v.ActivityId] = "专家访谈"
		case 5:
			mapResp[v.ActivityId] = "专家访谈"
		case 3:
			mapResp[v.ActivityId] = "上市公司小范围"
		case 8:
			mapResp[v.ActivityId] = "买方交流"
		}
	}
	return
}
